@@ -74,6 +74,10 @@ survey_header_aliases = {
     u"count": u"control::jr:count",
     u"repeat_count": u"control::jr:count",
     u"jr:count": u"control::jr:count",
+    u"autoplay": u"control::autoplay",
+    #New elements that have to go into itext elements:
+    #u"noAppErrorString" : u"itext::noAppErrorString",
+    #u"requiredMsg" : u"itext::requiredMsg",
 }
 list_header_aliases = {
     u"caption" : constants.LABEL,
@@ -528,6 +532,10 @@ def workbook_to_json(workbook_dict, form_name=None, default_language=u"default",
                 if not cascading_prefix:
                     raise PyXFormError(rowFormatString % row_number + " Cascading select needs a name.")
                 #cascading_json = get_cascading_json(cascading_choices, cascading_prefix, cascading_level)
+                if len(cascading_choices) <= 0 or not cascading_choices[0].has_key('questions'):
+                    raise PyXFormError(
+                        "Found a cascading_select " + cascading_level + ", but could not"
+                        " find " + cascading_level + "in cascades sheet.")
                 cascading_json = cascading_choices[0]['questions']
                 json_dict['choices'] = choices
                 for cq in cascading_json:
@@ -587,8 +595,9 @@ def workbook_to_json(workbook_dict, form_name=None, default_language=u"default",
                     
                 new_json_dict = row.copy()
                 new_json_dict[constants.TYPE] = select_type
-                new_json_dict['itemset'] = list_name
+                
                 if row.get('choice_filter'):
+                    new_json_dict['itemset'] = list_name
                     json_dict['choices'] = choices
                 else:
                     new_json_dict[constants.CHOICES] = choices[list_name]
@@ -632,6 +641,22 @@ def workbook_to_json(workbook_dict, form_name=None, default_language=u"default",
         if settings.get("public_key"):
             raise PyXFormError("Cannot omit instanceID, it is required for encryption.")
     else:
+        meta_children = [{
+            "name": "instanceID",
+            "bind": {
+                     "readonly": "true()",
+                     "calculate": settings.get("instanceID", "concat('uuid:', uuid())"),
+                     }, 
+            "type": "calculate",
+            }]
+        if 'instanceName' in settings:
+            meta_children.append({
+                "name": "instanceName",
+                "bind": {
+                    "calculate": settings['instanceName']
+                },
+                "type": "calculate",
+                })
         meta_element = \
         {
         "name":"meta",
@@ -639,14 +664,7 @@ def workbook_to_json(workbook_dict, form_name=None, default_language=u"default",
         "control": {
                     "bodyless": True
                     },
-        "children": [{
-                    "name": "instanceID",
-                    "bind": {
-                             "readonly": "true()",
-                             "calculate": "concat('uuid:', uuid())"
-                             }, 
-                    "type": "calculate",
-                    }]
+        "children": meta_children
         }
         noop, survey_children_array = stack[0]
         survey_children_array.append(meta_element)
